package com.jz.common.persistence;

import java.io.ByteArrayInputStream;
import java.io.UnsupportedEncodingException;
import java.sql.Blob;
import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;

import org.apache.ibatis.type.BaseTypeHandler;
import org.apache.ibatis.type.JdbcType;

import com.jz.common.utils.GZIPUtils;

public class CBTZipHandler extends BaseTypeHandler<String> {

    private static final String DEFAULT_CHARSET = "utf-8";

    @Override
    public void setNonNullParameter(PreparedStatement ps, int i, String parameter, JdbcType jdbcType)
            throws SQLException {
        ByteArrayInputStream bis;
        try {
            bis = new ByteArrayInputStream(parameter.getBytes(DEFAULT_CHARSET));
        } catch (UnsupportedEncodingException e) {
            throw new RuntimeException("Blob Encoding Error!");
        }
        ps.setBinaryStream(i, bis, parameter.length());
    }

    @Override
    public String getNullableResult(ResultSet rs, String columnName) throws SQLException {
        int isGziped = -1;
        try {
            // getAllColumn(rs);
            isGziped = rs.getInt("is_gziped");
        } catch (SQLException e) {
            System.out.println("获取是否压缩字段列数据发生异常:" + e.getMessage());
        }
        return getConvertString(rs.getBlob(columnName), isGziped);
    }

    @Override
    public String getNullableResult(CallableStatement cs, int columnIndex) throws SQLException {
        int isGziped = -1;
        try {
            // getAllColumn(cs.getResultSet());
            System.out.println("==========>>>CallableStatement解压缩");
            isGziped = cs.getInt("is_gziped");
        } catch (SQLException e) {
            System.out.println("获取是否压缩字段列数据发生异常:" + e.getMessage());
        }
        return getConvertString(cs.getBlob(columnIndex), isGziped);
    }

    @Override
    public String getNullableResult(ResultSet arg0, int arg1) throws SQLException {
        return null;
    }

    private String getConvertString(Blob blob, int isGziped) throws SQLException {
        byte[] returnValue = null;
        if (null != blob) {
            returnValue = blob.getBytes(1, (int) blob.length());
        }
        if (returnValue == null) return "";
        try {
            // 压缩状态
            if (isGziped == 1) {
                return GZIPUtils.unGzipString(returnValue, DEFAULT_CHARSET);
            } else {
                return new String(returnValue, DEFAULT_CHARSET);
            }
        } catch (Exception e) {
            throw new RuntimeException("Blob Encoding Error!");
        }
    }

    private String[] getAllColumn(ResultSet rs) throws SQLException {
        if (null != rs) {
            ResultSetMetaData rsmd = rs.getMetaData();
            int count = rsmd.getColumnCount();
            String[] name = new String[count];
            for (int i = 0; i < count; i++) {
                name[i] = rsmd.getColumnName(i + 1);
                System.out.println(name[i]);
            }
            return name;
        } else {
            return null;
        }
    }
}
