package com.jz.dmp.modules.controller.dataService;

import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.dmp.modules.controller.DataIntegration.bean.SourceDbNameListDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.SoureAndTargetColumnsReq;
import com.jz.dmp.modules.controller.dataService.bean.*;
import com.jz.dmp.modules.service.DmpApiMangeService;
import com.jz.dmp.modules.service.DmpApiServiceMangeService;
import com.jz.dmp.modules.service.OfflineSynchService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * 数据服务-服务管理--调用gateway 接口
 *
 * @author Bellamy
 * @since 2021-01-18 10:56:18
 */
@RestController
@RequestMapping("/apiService")
@Api(tags = "数据服务-服务管理")
public class DmpApiServiceMangeController {

    private static Logger logger = LoggerFactory.getLogger(DmpApiServiceMangeController.class);

    /**
     * 服务对象
     */
    @Autowired
    private DmpApiServiceMangeService dmpApiServiceMangeService;

    @Autowired
    private DmpApiMangeService dmpApiMangeService;

    @Autowired
    private OfflineSynchService offlineSynchService;

    /**
     * 制作/编辑API(第三方)基本信息
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    @ApiOperation(value = "制作/编辑API(第三方)和(大数据查询/标签查询)", notes = "保存/编辑API(第三方)")
    @PostMapping(value = "/saveApi")
    public JsonResult saveApiInfo(@RequestBody @Validated ApiInterfaceReq req, HttpServletRequest httpRequest) {
        JsonResult jsonResult = new JsonResult();
        try {
            if ("10004".equals(req.getApiType())) {
                jsonResult = dmpApiServiceMangeService.saveApiInfo(req);
            } else if ("10002".equals(req.getApiType())) {
                jsonResult = dmpApiServiceMangeService.saveApiBigDataInfo(req);
            }
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * 制作/编辑API(大数据查询/标签查询)
     *
     * @author Bellamy
     * @since 2021-01-19
     */
  /*  @ApiOperation(value = "制作/编辑API(大数据查询/标签查询)", notes = "制作/编辑API(大数据查询/标签查询)")
    @PostMapping(value = "/saveApiBigData")
    public JsonResult saveApiBigDataInfo(@RequestBody @Validated ApiInterfaceReq req, HttpServletRequest httpRequest) {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.saveApiBigDataInfo(req);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }*/

    /**
     * 编辑API(第三方)基本信息
     *
     * @author Bellamy
     * @since 2021-01-20
     */
/*    @ApiOperation(value = "编辑API(第三方)", notes = "编辑API(第三方)")
    @PostMapping(value = "/updataApi")
    public JsonResult updateApiInfo(@RequestBody @Validated ApiInterfaceReq req, HttpServletRequest httpRequest) {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.updateApiInfo(req);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }*/

    /**
     * 编辑API(大数据查询/标签查询)
     *
     * @author Bellamy
     * @since 2021-01-19
     */
   /* @ApiOperation(value = "编辑API(大数据查询/标签查询)", notes = "编辑API(大数据查询/标签查询)")
    @PostMapping(value = "/updateApiBigData")
    public JsonResult updateApiBigDataInfo(@RequestBody @Validated MakeBigDataApiReq req, HttpServletRequest httpRequest) {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.updateApiBigDataInfo(req);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }*/

    /**
     * API计量调用次数和执行时长
     *
     * @author Bellamy
     * @since 2021-01-20
     */
    @ApiOperation(value = "API计量--调用次数和执行时长", notes = "API计量调用次数和执行时长")
    @GetMapping(value = "/countAPiCallStat")
    //@ApiImplicitParam(name = "date", value = "date", required = true)
    public JsonResult countAPiCallStat(HttpServletRequest httpRequest) {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.getCountAPiCallStat();
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /*  *//**
     * API计量--API调用列表
     *
     * @author Bellamy
     * @since 2021-01-19
     *//*
    @ApiOperation(value = "API计量--API调用列表", notes = "API计量--API调用列表")
    @PostMapping(value = "/apiCountListPage")
    public JsonResult apiCountListPage(@RequestBody @Validated ApiInterfaceInfoListReq req, HttpServletRequest httpRequest) {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiMangeService.queryApiListPage(req);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }*/

    /**
     * API计量--API未调用列表
     *
     * @author Bellamy
     * @since 2021-01-22
     */
    @ApiOperation(value = "API计量--API未调用列表", notes = "API计量--API未调用列表")
    @PostMapping(value = "/notCalledList")
    public JsonResult apiNotCalledListPage(@RequestBody @Validated ApiInterfaceInfoListReq req, HttpServletRequest httpRequest) {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.queryApiNotCalledListPage(req);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * API计量--API已调用列表
     *
     * @author Bellamy
     * @since 2021-02-25
     */
    @ApiOperation(value = "API计量--API已调用列表", notes = "API计量--API已调用列表")
    @PostMapping(value = "/listCallApi")
    public JsonResult listCallApi(@RequestBody @Validated ApiInterfaceInfoListReq req, HttpServletRequest httpRequest) {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.listCallApi(req);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * 获取数据源库——下拉框
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "获取数据源库-下拉框", notes = "获取数据源库")
    @GetMapping(value = "/sourceDbList")
    @ApiImplicitParams({@ApiImplicitParam(name = "projectId", value = "项目id", required = true),
            @ApiImplicitParam(name = "dbName", value = "数据源类型名称", required = true)})
    public JsonResult<List<SourceDbNameListDto>> getSourceDbList(@RequestParam Integer projectId, @RequestParam String dbName) {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.querygSourceDbList(projectId, dbName);
        } catch (Exception e) {
            jsonResult.setMessage("查询失败");
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * 配置数据源——下拉框
     *
     * @return
     * @author Bellamy
     * @since 2021-01-21
     */
    @ApiOperation(value = "配置数据源-下拉框", notes = "配置数据源")
    @GetMapping(value = "/sourceSetting")
    public JsonResult getSourceSetting() throws Exception {
        return dmpApiServiceMangeService.getSourceSetting();
    }

    /**
     * 根据数据源库id,获取数据源表——下拉框
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "根据数据源库id,获取数据源表-下拉框", notes = "根据数据源库id,获取数据源表")
    @GetMapping(value = "/sourceTableList")
    @ApiImplicitParam(name = "sourceDbId", value = "数据源库id", required = true)
    public JsonResult getSourceTableList(@RequestParam Long sourceDbId, @RequestParam(value = "targetName", required = false) String targetName) throws Exception {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = offlineSynchService.querygSourceTableList(sourceDbId, targetName);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * 服务开发API列表
     *
     * @author Bellamy
     * @since 2021-02-24
     */
    @ApiOperation(value = "服务开发--API列表", notes = "服务开发API列表")
    @PostMapping(value = "/apiListPaging")
    public JsonResult apiListPaging(@RequestBody @Validated ApiInterfaceInfoListReq req, HttpServletRequest httpRequest) {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.apiListPaging(req);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * 获取文件夹列表
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "获取文件夹列表", notes = "获取文件夹列表")
    @GetMapping(value = "/folderTree")
    @ApiImplicitParams({@ApiImplicitParam(name = "projectId", value = "项目id"),
            @ApiImplicitParam(name = "orgFolder", value = "组织编码")})
    public JsonResult getFolderTree(@RequestParam(name = "projectId", required = false) String projectId, @RequestParam(name = "orgFolder", required = false) String orgFolder) {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.getFolderTree(projectId, orgFolder);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * 删除文件夹
     *
     * @return
     * @author Bellamy
     * @since 2021-03-3
     */
    @ApiOperation(value = "删除文件夹", notes = "删除文件夹")
    @GetMapping(value = "/delFolder")
    @ApiImplicitParam(name = "id", value = "文件夹id", required = true)
    public JsonResult delFolderById(@RequestParam String id) throws Exception {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.delFolderById(id);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * 服务开发---获取ApiId
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    @ApiOperation(value = "服务开发---获取ApiId", notes = "服务开发---获取ApiId")
    @PostMapping(value = "/getApiId")
    public JsonResult getApiId() {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.getApiId();
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * 创建/编辑项目文件夹
     *
     * @author Bellamy
     * @since 2021-02-24
     */
    @ApiOperation(value = "创建/编辑项目文件夹", notes = "创建/编辑项目文件夹")
    @PostMapping(value = "/createProjectFolder")
    public JsonResult createProjectFolder(@RequestBody @Validated CreateFolderReq req, HttpServletRequest httpRequest) {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.createProjectFolder(req);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * 获取function模板列表
     *
     * @return
     * @author Bellamy
     * @since 2021-03-3
     */
    @ApiOperation(value = "获取function模板列表", notes = "获取function模板列表")
    @GetMapping(value = "/functionTemplate")
    public JsonResult getFunctionTemplateList() throws Exception {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.getFunctionTemplateList();
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * 获取数据源表字段
     *
     * @return
     * @author Bellamy
     * @since 2021-01-21
     */
  /* @ApiOperation(value = "获取数据源表字段111", notes = "获取数据源表字段")
    @PostMapping(value = "/getTableColumns")
    public JsonResult getTableColumns() throws Exception {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = dmpApiServiceMangeService.test();
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }*/

}