package com.jz.dmp.modules.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.constant.StatuConstant;
import com.jz.dmp.modules.controller.bean.DmpTableFieldSchemaDto;
import com.jz.dmp.modules.controller.bean.DmpTableFieldSchemaRequest;
import com.jz.dmp.modules.dao.DmpTableFieldSchemaDao;
import com.jz.dmp.modules.model.DmpTableFieldSchema;
import com.jz.dmp.modules.service.DmpTableFieldSchemaService;

/**
 * 项目表字段类型(DmpTableFieldSchema)表服务实现类
 *
 * @author Bellamy
 * @since 2020-12-23 16:34:55
 */
@Service("dmpTableFieldSchemaService")
public class DmpTableFieldSchemaServiceImpl implements DmpTableFieldSchemaService {
    @Autowired
    private DmpTableFieldSchemaDao dmpTableFieldSchemaDao;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @Override
    public DmpTableFieldSchema queryById(Integer id) {
        return this.dmpTableFieldSchemaDao.queryById(id);
    }

    /**
     * 查询多条数据
     *
     * @param offset 查询起始位置
     * @param limit  查询条数
     * @return 对象列表
     */
    @Override
    public List<DmpTableFieldSchema> queryAllByLimit(int offset, int limit) {
        return this.dmpTableFieldSchemaDao.queryAllByLimit(offset, limit);
    }

    /**
     * 新增数据
     *
     * @param dmpTableFieldSchema 实例对象
     * @return 实例对象
     */
    @Override
    public DmpTableFieldSchema insert(DmpTableFieldSchema dmpTableFieldSchema) {
        this.dmpTableFieldSchemaDao.insert(dmpTableFieldSchema);
        return dmpTableFieldSchema;
    }

    /**
     * 修改数据
     *
     * @param dmpTableFieldSchema 实例对象
     * @return 实例对象
     */
    @Override
    public DmpTableFieldSchema update(DmpTableFieldSchema dmpTableFieldSchema) {
        this.dmpTableFieldSchemaDao.update(dmpTableFieldSchema);
        return this.queryById(dmpTableFieldSchema.getId());
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer id) {
        return this.dmpTableFieldSchemaDao.deleteById(id) > 0;
    }
    
    /*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpTableFieldSchemaService#findList(com.ycxc.vmts.controller.
	 * bean.DmpTableFieldSchemaRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public BaseBeanResponse<DmpTableFieldSchemaDto> findList(DmpTableFieldSchemaRequest dmpTableFieldSchemaRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpTableFieldSchemaDto> baseBeanResponse = new BaseBeanResponse<>();

		Map<String, Object> param = new HashMap<>();
		//ID
		if (dmpTableFieldSchemaRequest.getId() != null) {
			param.put("id", dmpTableFieldSchemaRequest.getId());
		}
		//数据源类型主键
		if (dmpTableFieldSchemaRequest.getDstId() != null) {
			param.put("dstId", dmpTableFieldSchemaRequest.getDstId());
		}
		//类型类别
		if (!StringUtils.isEmpty(dmpTableFieldSchemaRequest.getTypeCategory())) {
			param.put("typeCategory", dmpTableFieldSchemaRequest.getTypeCategory());
		}
		//字段类型
		if (!StringUtils.isEmpty(dmpTableFieldSchemaRequest.getFieldType())) {
			param.put("fieldType", dmpTableFieldSchemaRequest.getFieldType());
		}
		//是否类别的默认映射
		if (!StringUtils.isEmpty(dmpTableFieldSchemaRequest.getIsCatDefault())) {
			param.put("isCatDefault", dmpTableFieldSchemaRequest.getIsCatDefault());
		}
		
		//加上可用标识（未软删除）
		param.put("dataStatu", "1");

		List<DmpTableFieldSchemaDto> list = dmpTableFieldSchemaDao.findList(param);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setDatas(list);
		return baseBeanResponse;
	}
}