package com.jz.dmp.modules.service.projconfig.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.StatuConstant;
import com.jz.common.persistence.BaseService;
import com.jz.dmp.modules.controller.projconfig.bean.DmpProjectConfigEngineDto;
import com.jz.dmp.modules.controller.projconfig.bean.DmpProjectConfigInfoBatch;
import com.jz.dmp.modules.controller.projconfig.bean.DmpProjectConfigInfoDto;
import com.jz.dmp.modules.controller.projconfig.bean.DmpProjectConfigInfoRequest;
import com.jz.dmp.modules.controller.projconfig.bean.DmpProjectEngineParamDto;
import com.jz.dmp.modules.controller.projconfig.bean.DmpPublicConfigInfoDto;
import com.jz.dmp.modules.controller.projconfig.bean.DmpPublicConfigInfoRequest;
import com.jz.dmp.modules.dao.projconfig.DmpProjectConfigEngineMapper;
import com.jz.dmp.modules.dao.projconfig.DmpProjectConfigInfoMapper;
import com.jz.dmp.modules.dao.projconfig.DmpProjectEngineParamMapper;
import com.jz.dmp.modules.model.DmpProjectConfigEngine;
import com.jz.dmp.modules.model.DmpProjectConfigInfo;
import com.jz.dmp.modules.model.DmpProjectEngineParam;
import com.jz.dmp.modules.service.projconfig.DmpProjectConfigInfoService;
import com.jz.dmp.modules.service.projconfig.DmpPublicConfigInfoService;

/**
 * 项目配置表服务的实现?
 * 
 * @author ybz
 *
 */
@Service("dmpProjectConfigInfoService")
public class DmpProjectConfigInfoServiceImpl extends BaseService implements DmpProjectConfigInfoService {

	private static Logger logger = LoggerFactory.getLogger(DmpProjectConfigInfoServiceImpl.class);

	@Autowired
	private DmpProjectConfigInfoMapper dmpProjectConfigInfoMapper;
	@Autowired
	private DmpProjectConfigEngineMapper dmpProjectConfigEngineMapper;
	@Autowired
	private DmpProjectEngineParamMapper dmpProjectEngineParamMapper;
	
	@Autowired
	private DmpPublicConfigInfoService dmpPublicConfigInfoService;

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectConfigInfoService#findList(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectConfigInfoRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public PageInfoResponse<DmpProjectConfigInfoDto> findListWithPage(DmpProjectConfigInfoRequest dmpProjectConfigInfoRequest, HttpServletRequest httpRequest)
			throws Exception {
		PageInfoResponse<DmpProjectConfigInfoDto> pageInfoResponse = new PageInfoResponse<>();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpProjectConfigInfoRequest.getProjectConfigId() != null) {
			param.put("projectConfigId", dmpProjectConfigInfoRequest.getProjectConfigId());
		}
		//项目主键
		if (dmpProjectConfigInfoRequest.getProjectId() != null) {
			param.put("projectId", dmpProjectConfigInfoRequest.getProjectId());
		}
		//备注
		if (!StringUtils.isEmpty(dmpProjectConfigInfoRequest.getRemark())) {
			param.put("remark", dmpProjectConfigInfoRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpProjectConfigInfoRequest.getDataStatus())) {
			param.put("dataStatus", dmpProjectConfigInfoRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpProjectConfigInfoRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpProjectConfigInfoRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpProjectConfigInfoRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpProjectConfigInfoRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpProjectConfigInfoRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpProjectConfigInfoRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpProjectConfigInfoRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpProjectConfigInfoRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpProjectConfigInfoRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpProjectConfigInfoRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpProjectConfigInfoRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpProjectConfigInfoRequest.getUpdateTimeEnd());
		}

		PageHelper.startPage(dmpProjectConfigInfoRequest.getPageNum(), dmpProjectConfigInfoRequest.getPageSize());
		List<DmpProjectConfigInfoDto> list = dmpProjectConfigInfoMapper.findList(param);
		PageInfo<DmpProjectConfigInfoDto> pageInfo = new PageInfo<>(list);

		pageInfoResponse.setCode(StatuConstant.SUCCESS_CODE);
		pageInfoResponse.setMessage("查询成功");
		pageInfoResponse.setData(pageInfo);
		return pageInfoResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectConfigInfoService#findList(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectConfigInfoRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public BaseBeanResponse<DmpProjectConfigInfoDto> findList(DmpProjectConfigInfoRequest dmpProjectConfigInfoRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpProjectConfigInfoDto> baseBeanResponse = new BaseBeanResponse<>();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpProjectConfigInfoRequest.getProjectConfigId() != null) {
			param.put("projectConfigId", dmpProjectConfigInfoRequest.getProjectConfigId());
		}
		//项目主键
		if (dmpProjectConfigInfoRequest.getProjectId() != null) {
			param.put("projectId", dmpProjectConfigInfoRequest.getProjectId());
		}
		//备注
		if (!StringUtils.isEmpty(dmpProjectConfigInfoRequest.getRemark())) {
			param.put("remark", dmpProjectConfigInfoRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpProjectConfigInfoRequest.getDataStatus())) {
			param.put("dataStatus", dmpProjectConfigInfoRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpProjectConfigInfoRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpProjectConfigInfoRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpProjectConfigInfoRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpProjectConfigInfoRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpProjectConfigInfoRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpProjectConfigInfoRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpProjectConfigInfoRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpProjectConfigInfoRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpProjectConfigInfoRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpProjectConfigInfoRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpProjectConfigInfoRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpProjectConfigInfoRequest.getUpdateTimeEnd());
		}
		
		//加上可用标识（未软删除）
		param.put("dataStatu", "1");

		List<DmpProjectConfigInfoDto> list = dmpProjectConfigInfoMapper.findList(param);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setDatas(list);
		return baseBeanResponse;
	}


	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectConfigInfoService#add(com.ycxc.vmts.entity.DmpProjectConfigInfo,
	 * javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpProjectConfigInfo> add(DmpProjectConfigInfo dmpProjectConfigInfo, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpProjectConfigInfo> baseBeanResponse = new BaseBeanResponse<>();

		/*$*setProjectConfigIdCodeReplace*$*/
		// 创建人
		dmpProjectConfigInfo.setCreateUserId(getHttpRequestUserId(httpRequest));
		// 创建时间
		dmpProjectConfigInfo.setCreateTime(new Date());

		dmpProjectConfigInfoMapper.insertSelective(dmpProjectConfigInfo);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("新增成功");
		baseBeanResponse.setData(dmpProjectConfigInfo);

		return baseBeanResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectConfigInfoService#edit(com.ycxc.vmts.entity.DmpProjectConfigInfo,
	 * javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpProjectConfigInfo> edit(DmpProjectConfigInfo dmpProjectConfigInfo, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpProjectConfigInfo> baseBeanResponse = new BaseBeanResponse<>();

		// 修改人
		dmpProjectConfigInfo.setUpdateUserId(getHttpRequestUserId(httpRequest));
		// 修改时间
		dmpProjectConfigInfo.setUpdateTime(new Date());

		dmpProjectConfigInfoMapper.updateByPrimaryKeySelective(dmpProjectConfigInfo);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("修改成功");
		baseBeanResponse.setData(dmpProjectConfigInfo);

		return baseBeanResponse;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectConfigInfoService#addOrEdit(com.ycxc.vmts.entity.DmpProjectConfigInfo,
	 * javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpProjectConfigInfo> addOrEdit(DmpProjectConfigInfo dmpProjectConfigInfo, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpProjectConfigInfo> baseBeanResponse = new BaseBeanResponse<>();
		
		Integer projectConfigId = dmpProjectConfigInfo.getProjectConfigId();
		
		if (null==projectConfigId) {//新增
			// 创建人
			dmpProjectConfigInfo.setCreateUserId(getHttpRequestUserId(httpRequest));
			// 创建时间
			dmpProjectConfigInfo.setCreateTime(new Date());

			dmpProjectConfigInfoMapper.insertSelective(dmpProjectConfigInfo);
			
			//保存选择的引擎
			List<DmpProjectConfigEngine> dmpProjectConfigEngines = dmpProjectConfigInfo.getDmpProjectConfigEngines();
			for (DmpProjectConfigEngine dmpProjectConfigEngine : dmpProjectConfigEngines) {
				
				dmpProjectConfigEngine.setConfigId(dmpProjectConfigInfo.getProjectConfigId());
				dmpProjectConfigEngine.setDataStatus("1");
				dmpProjectConfigEngine.setCreateUserId(getHttpRequestUserId(httpRequest));
				dmpProjectConfigEngine.setCreateTime(new Date());
				
				dmpProjectConfigEngineMapper.insert(dmpProjectConfigEngine);
				
				//保存填写的私有引擎参数
				List<DmpProjectEngineParam> dmpProjectEngineParams = dmpProjectConfigEngine.getDmpProjectEngineParams();
				dmpProjectEngineParams = dmpProjectEngineParams.stream().map(x->{
					x.setConfigEngineId(dmpProjectConfigEngine.getConfigEngineId());
					x.setDataStatus("1");
					x.setCreateUserId(getHttpRequestUserId(httpRequest));
					x.setCreateTime(new Date());
					return x;
				}).collect(Collectors.toList());
				
				dmpProjectEngineParamMapper.insertBatch(dmpProjectEngineParams);
			}

			baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
			baseBeanResponse.setMessage("新增成功");
			baseBeanResponse.setData(dmpProjectConfigInfo);
		} else {//修改
			// 修改人
			dmpProjectConfigInfo.setUpdateUserId(getHttpRequestUserId(httpRequest));
			// 修改时间
			dmpProjectConfigInfo.setUpdateTime(new Date());
			
			dmpProjectConfigInfoMapper.updateByPrimaryKeySelective(dmpProjectConfigInfo);
			
			//保存选择的引擎
			Map<String, Object> projConfigEngineParam = new HashMap<String, Object>();
			projConfigEngineParam.put("projectId", dmpProjectConfigInfo.getProjectId());
			List<DmpProjectConfigEngineDto> dmpProjConfigEngineDtosDb = dmpProjectConfigEngineMapper.findList(projConfigEngineParam);
			
			List<DmpProjectConfigEngine> dmpProjConfigEngines = dmpProjectConfigInfo.getDmpProjectConfigEngines();
			
			//新增
			List<DmpProjectConfigEngine> dmpProjConfigEnginesNew = dmpProjConfigEngines.stream()
					.filter(x->{
						if (x.getConfigEngineId()==null) {
							return true;
						}
						return false;
					}).map(y->{
						y.setCreateUserId(getHttpRequestUserId(httpRequest));
						y.setCreateTime(new Date());
						return y;
					}).collect(Collectors.toList());
			dmpProjectConfigEngineMapper.insertBatch(dmpProjConfigEnginesNew);
			
			//修改
			List<DmpProjectConfigEngine> dmpProjConfigEnginesUpdate = dmpProjConfigEngines.parallelStream()
					.filter(x->{
						if (x.getConfigEngineId()==null) {
							return false;
						}
						return true;
					})
					.collect(Collectors.toList());
			for (DmpProjectConfigEngine dmpProjectConfigEngine : dmpProjConfigEnginesUpdate) {
				dmpProjectConfigEngine.setUpdateUserId(getHttpRequestUserId(httpRequest));
				dmpProjectConfigEngine.setUpdateTime(new Date());
				dmpProjectConfigEngineMapper.updateByPrimaryKeySelective(dmpProjectConfigEngine);
			}
			
			//删除
			Map<Integer, Integer> dicMap = dmpProjConfigEnginesUpdate.parallelStream()
					.collect(Collectors.toMap(DmpProjectConfigEngine::getConfigEngineId, DmpProjectConfigEngine::getConfigEngineId));
			
			List<Integer> deleteIds = new ArrayList<Integer>();
			
			dmpProjConfigEngineDtosDb.parallelStream().forEach(x->{
				if (dicMap.get(x.getConfigEngineId())==null) {
					deleteIds.add(x.getConfigEngineId());
				}
			});
			dmpProjectConfigEngineMapper.deleteByIds(deleteIds);
			
			//保存填写的私有引擎参数
			Map<String, Object> projEngineParamMap = new HashMap<String, Object>();
			projEngineParamMap.put("projectId", dmpProjectConfigInfo.getProjectId());
			List<DmpProjectEngineParamDto> dmpProjEngineParamDtosDb = dmpProjectEngineParamMapper.findList(projEngineParamMap);
			
			List<DmpProjectEngineParam> dmpProjectEngineParams = dmpProjConfigEngines.stream()
					.flatMap(x->{
						return x.getDmpProjectEngineParams().stream();
					}).collect(Collectors.toList());
			dmpProjectEngineParamMapper.insertBatch(dmpProjectEngineParams);
			
			//新增
			List<DmpProjectEngineParam> dmpProjectEngineParamsNew = dmpProjectEngineParams.stream()
					.filter(x->{
						if (x.getProjectParamId()==null) {
							return true;
						}
						return false;
					}).map(y->{
						y.setCreateUserId(getHttpRequestUserId(httpRequest));
						y.setCreateTime(new Date());
						return y;
					}).collect(Collectors.toList());
			dmpProjectEngineParamMapper.insertBatch(dmpProjectEngineParamsNew);
			
			//修改
			List<DmpProjectEngineParam> dmpProjEngineParamsUpdate = dmpProjectEngineParams.parallelStream()
					.filter(x->{
						if (x.getProjectParamId()==null) {
							return false;
						}
						return true;
					})
					.collect(Collectors.toList());
			for (DmpProjectEngineParam dmpProjectEngineParam : dmpProjEngineParamsUpdate) {
				dmpProjectEngineParam.setUpdateUserId(getHttpRequestUserId(httpRequest));
				dmpProjectEngineParam.setUpdateTime(new Date());
				dmpProjectEngineParamMapper.updateByPrimaryKeySelective(dmpProjectEngineParam);
			}
			//删除
			Map<Integer, Integer> dicParamMap = dmpProjEngineParamsUpdate.parallelStream()
					.collect(Collectors.toMap(DmpProjectEngineParam::getProjectParamId, DmpProjectEngineParam::getProjectParamId));
			
			List<Integer> deleteParamIds = new ArrayList<Integer>();
			
			dmpProjEngineParamDtosDb.parallelStream().forEach(x->{
				if (dicParamMap.get(x.getProjectParamId())==null) {
					deleteParamIds.add(x.getProjectParamId());
				}
			});
			dmpProjectEngineParamMapper.deleteByIds(deleteParamIds);

			baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
			baseBeanResponse.setMessage("修改成功");
			baseBeanResponse.setData(dmpProjectConfigInfo);
		}
		
		return baseBeanResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectConfigInfoService#findById(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectConfigInfoRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public BaseBeanResponse<DmpProjectConfigInfoDto> findById(Integer projectConfigId, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpProjectConfigInfoDto> baseBeanResponse = new BaseBeanResponse<>();

		DmpProjectConfigInfoDto dmpProjectConfigInfoDto = dmpProjectConfigInfoMapper.findById(projectConfigId);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setData(dmpProjectConfigInfoDto);

		return baseBeanResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectConfigInfoService#deleteById(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectConfigInfoRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse deleteById(Integer projectConfigId, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpProjectConfigInfoMapper.deleteByPrimaryKey(projectConfigId);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectConfigInfoService#deleteById(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectConfigInfoRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse softDeleteById(Integer projectConfigId, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpProjectConfigInfoMapper.softDeleteByPrimaryKey(projectConfigId);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("软删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectConfigInfoService#deleteById(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectConfigInfoRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse delete(DmpProjectConfigInfoRequest dmpProjectConfigInfoRequest, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpProjectConfigInfoRequest.getProjectConfigId() != null) {
			param.put("projectConfigId", dmpProjectConfigInfoRequest.getProjectConfigId());
		}
		//项目主键
		if (dmpProjectConfigInfoRequest.getProjectId() != null) {
			param.put("projectId", dmpProjectConfigInfoRequest.getProjectId());
		}
		//备注
		if (!StringUtils.isEmpty(dmpProjectConfigInfoRequest.getRemark())) {
			param.put("remark", dmpProjectConfigInfoRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpProjectConfigInfoRequest.getDataStatus())) {
			param.put("dataStatus", dmpProjectConfigInfoRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpProjectConfigInfoRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpProjectConfigInfoRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpProjectConfigInfoRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpProjectConfigInfoRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpProjectConfigInfoRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpProjectConfigInfoRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpProjectConfigInfoRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpProjectConfigInfoRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpProjectConfigInfoRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpProjectConfigInfoRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpProjectConfigInfoRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpProjectConfigInfoRequest.getUpdateTimeEnd());
		}

		dmpProjectConfigInfoMapper.delete(param);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectConfigInfoService#deleteById(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectConfigInfoRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse softDelete(DmpProjectConfigInfoRequest dmpProjectConfigInfoRequest, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpProjectConfigInfoRequest.getProjectConfigId() != null) {
			param.put("projectConfigId", dmpProjectConfigInfoRequest.getProjectConfigId());
		}
		//项目主键
		if (dmpProjectConfigInfoRequest.getProjectId() != null) {
			param.put("projectId", dmpProjectConfigInfoRequest.getProjectId());
		}
		//备注
		if (!StringUtils.isEmpty(dmpProjectConfigInfoRequest.getRemark())) {
			param.put("remark", dmpProjectConfigInfoRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpProjectConfigInfoRequest.getDataStatus())) {
			param.put("dataStatus", dmpProjectConfigInfoRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpProjectConfigInfoRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpProjectConfigInfoRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpProjectConfigInfoRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpProjectConfigInfoRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpProjectConfigInfoRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpProjectConfigInfoRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpProjectConfigInfoRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpProjectConfigInfoRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpProjectConfigInfoRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpProjectConfigInfoRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpProjectConfigInfoRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpProjectConfigInfoRequest.getUpdateTimeEnd());
		}

		dmpProjectConfigInfoMapper.softDelete(param);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("软删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpProjectConfigInfoService#addBatch(com.ycxc.vmts.controller.bas.
	 * bean.DmpProjectConfigInfoVo, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpProjectConfigInfoBatch> addBatch(DmpProjectConfigInfoBatch dmpProjectConfigInfoBatch, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpProjectConfigInfoBatch> baseBeanResponse = new BaseBeanResponse<>();

		List<DmpProjectConfigInfo> dmpProjectConfigInfos = dmpProjectConfigInfoBatch.getDmpProjectConfigInfos();

		if (CollectionUtils.isEmpty(dmpProjectConfigInfos)) {
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			baseBeanResponse.setMessage("数据不能为空！");
			return baseBeanResponse;
		}

		dmpProjectConfigInfos = dmpProjectConfigInfos.stream().map(dmpProjectConfigInfo -> {
			/*$*setProjectConfigIdCodeReplace*$*/
			// 创建人
			try {
				dmpProjectConfigInfo.setCreateUserId(getHttpRequestUserId(httpRequest));
			} catch (Exception e) {
				logger.info(e.getMessage());
				e.printStackTrace();
			}
			// 创建时间
			dmpProjectConfigInfo.setCreateTime(new Date());

			return dmpProjectConfigInfo;
		}).collect(Collectors.toList());

		dmpProjectConfigInfoMapper.insertBatch(dmpProjectConfigInfos);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("批量新增成功");
		baseBeanResponse.setData(dmpProjectConfigInfoBatch);

		return baseBeanResponse;
	}

	/**
	 *批量删除
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseResponse deleteByIds(List<Integer> idList, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpProjectConfigInfoMapper.deleteByIds(idList);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("删除成功");

		return baseResponse;
	}

	/**
	 *批量软删除
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseResponse softDeleteByIds(List<Integer> idList, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpProjectConfigInfoMapper.softDeleteByIds(idList);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("软删除成功");

		return baseResponse;
	}

	/**
	 *获取项目配置信息
	 */
	@Override
	public BaseBeanResponse<DmpProjectConfigInfoDto> findByProjectId(Integer projectId, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpProjectConfigInfoDto> baseBeanResponse = new BaseBeanResponse<DmpProjectConfigInfoDto>();
		
		Map<String, Object> param = new HashMap<String, Object>();
		param.put("projectId", projectId);
		DmpProjectConfigInfoDto dto = null;
		List<DmpProjectConfigInfoDto> list = dmpProjectConfigInfoMapper.findList(param);
		
		if (!CollectionUtils.isEmpty(list)) {
			dto = list.get(0);
			//设置公共属性
			DmpPublicConfigInfoRequest request = new DmpPublicConfigInfoRequest();
			BaseBeanResponse<DmpPublicConfigInfoDto> configInfoBeanResponse = dmpPublicConfigInfoService.findList(request, null);
			List<DmpPublicConfigInfoDto> configInfoDtos = configInfoBeanResponse.getDatas();
			if (!CollectionUtils.isEmpty(configInfoDtos)) {
				dto.setDmpPublicConfigInfoDto(configInfoDtos.get(0));
			}
		}
		
		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setData(dto);
		return baseBeanResponse;
	}

}
